#!/usr/bin/env python
#-*- coding:utf-8 -*-
#===============================================================================
#  Copyright (C) 2010 Schaefer & Tobies SuC GmbH.
#  Author: Markus Grimm <mgr@schaefer-tobies.de>
#
#  This file is part of Pyontapi.
#
#  Pyontapi is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyontapi is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with Pyontapi.  If not, see <http://www.gnu.org/licenses/>.
#
#===============================================================================

""" Command-Line tool for listing API commands for filer """

import os
import sys

def main():
    """ main function """
    basedir = os.path.join(
        os.path.dirname(__file__), os.pardir, os.pardir, os.pardir
    )
    try:
        __import__('schtob.pyontapi')
    except ImportError:
        sys.path.append(basedir)
    
    from schtob.pyontapi import NaFiler, errors
    from schtob.pyontapi.settings import NA_CONFIG
    
    filer_name = raw_input('Filer: ')
    if not filer_name:
        sys.exit(0)
    
    print "listing packages..."
    
    try:
        filer = NaFiler(filer_name, NA_CONFIG)
        result = filer.get_api_module('system').api_list()
    except errors.APIFailure, exc:
        print exc
        sys.exit(1)
    packages = {}
    commands = []
    for api in result['apis']:
        package = api['name'].split('-')[0]
        commands.append(api['name'])
        if not package in packages:
            packages[package] = []
            print ' - ' + package
        packages[package].append(api['name'])
    
    while True:
        entry = raw_input('Enter package or command (leave empty to exit): ')
        if not entry:
            break
        elif entry not in packages and entry not in commands:
            print "no such package or command..."
        elif entry in commands:
            print_command(filer, entry)
        else:
            for api in packages[entry]:
                print api

def print_command(filer, command):
    """ print input and output fields for command ``command`` """
    result = filer.get_api_module('system').api_get_elements([command])
    output = []
    print "Input fields:"
    for entry in result['api-entries'][0]['api-elements']:
        if entry.get('is-output', False):
            output.append(entry)
        else:
            print " - %s:%s optional:%s" % (
                entry['name'], entry['type'], 
                entry.get('is-optional', False)
            )
    print "Output fields:"
    for entry in output:
        print " - %s:%s" % (entry['name'], entry['type']) 
    
if __name__ == '__main__':
    try:
        main()
    except KeyboardInterrupt:
        print ""
    except EOFError:
        print ""